# pyasjp
Programmatic access to data in ASJP's text format

[![Build Status](https://travis-ci.org/shh-dlce/pyasjp.svg?branch=master)](https://travis-ci.org/shh-dlce/pyasjp)
[![codecov](https://codecov.io/gh/shh-dlce/pyasjp/branch/master/graph/badge.svg)](https://codecov.io/gh/shh-dlce/pyasjp)
[![PyPI](https://img.shields.io/pypi/v/pyasjp.svg)](https://pypi.org/project/pyasjp)

